@@ -30,8 +30,8 @@ pureseqtmr_report <- function(
       )
     )
   }
-  kat("***************")
-  kat("* sessionInfo *")
-  kat("***************")
-  print(utils::sessionInfo())
+  kat("****************")
+  kat("* session info *")
+  kat("****************")
+  message(paste0(devtools::session_info(), collapse = "\n"))
 }
