@@ -25,8 +25,7 @@ run_pureseqtm_proteome <- function(
   folder_name = get_default_pureseqtm_folder(),
   topology_filename = tempfile(fileext = ".top")
 ) {
-  pureseqtmr::check_pureseqtm_installation(folder_name)
-
+  # Check FASTA file and installation in 'create_pureseqtm_proteome_file'
   filename <- pureseqtmr::create_pureseqtm_proteome_file(
     fasta_filename = fasta_filename,
     topology_filename = topology_filename,
